@@ -6,6 +6,7 @@
 import anndata as ad
 import scanpy as sc
 import numpy as np
+from scipy import sparse
 import pandas as pd
 
 
@@ -118,6 +119,20 @@ def filterAnnDatas(dataset, patterns, geneColumnName):
     print(patterns_filtered.shape, "patterns filter shape")
     dataset_filtered.X[dataset_filtered.X < 0] = 0
     patterns_filtered.X[patterns_filtered.X < 0] = 0
+    # Normalize both dataset and pattern columns to 5 L1
+    if sparse.issparse(patterns_filtered.X):
+        patterns_filtered.X = patterns_filtered.X.toarray()
+
+    norm = np.linalg.norm(patterns_filtered.X, axis=1, ord=1, keepdims=True)
+    normalized = patterns_filtered.X / (norm * .2)
+    patterns_filtered.X = normalized
+
+    if sparse.issparse(dataset_filtered.X):
+        dataset_filtered.X = dataset_filtered.X.toarray()
+
+    dnorm = np.linalg.norm(dataset_filtered.X, axis=1, ord=1, keepdims=True)
+    dnormalized = dataset_filtered.X / (dnorm * .2)
+    dataset_filtered.X = dnormalized
     return dataset_filtered, patterns_filtered
 
 
@@ -127,8 +142,6 @@ def logTransform(dataset_filtered):
     :param dataset_filtered: Anndata object cells x genes
     :return: Log tranform of dataset and patterns.
     """
-    print(np.mean(dataset_filtered.X))
     dataset_filtered.layers['log'] = np.log1p(dataset_filtered.X)
     print("A layer named 'log' has been added to your filtered dataset")
-    # print(np.argwhere(np.isnan(dataset_filtered.X)))
     return dataset_filtered
