@@ -183,7 +183,7 @@ def UMAP_Viz(dataset_filtered, UMAPName, cellTypeColumnName, colorScheme='Paired
         handles = []
         for i in range(numTypes):
             handles.append(mpatches.Patch(color=(sns.color_palette(colorScheme, n_colors=numTypes)[i]),
-                                          label=subsetted.obs['Main_cluster_name'].unique()[i]))
+                                          label=subsetted.obs[cellTypeColumnName].unique()[i]))
         plt.legend(handles=handles, title="Cell Types", fontsize='xx-small', loc='best')
         if display is True and path is None:
             plt.show()
@@ -231,9 +231,6 @@ def featurePlots(dataset_filtered, num_patterns, projectionName, UMAPName, obsCo
                         s=pointSize)
             plt.colorbar()
             print("Number of nonzero cells " + str(np.count_nonzero(feature)))
-            print("Percentage of nonzero cells " + str((np.count_nonzero(feature) / dataset_filtered.shape[0]) * 100))
-            print("Max coefficient " + str(np.max(feature)))
-            print("Average coefficient " + str(np.mean(feature)))
             if path is None:
                 plt.show()
             if path is not None and display is True:
@@ -249,9 +246,6 @@ def featurePlots(dataset_filtered, num_patterns, projectionName, UMAPName, obsCo
             plt.scatter(data.obsm[UMAPName][:, 0], data.obsm[UMAPName][:, 1], c=feature, cmap=cmap, s=pointSize)
             plt.colorbar()
             print("Number of nonzero cells " + str(np.count_nonzero(feature)))
-            print("Percentage of nonzero cells " + str((np.count_nonzero(feature) / dataset_filtered.shape[0]) * 100))
-            print("Max coefficient " + str(np.max(feature)))
-            print("Average coefficient " + str(np.mean(feature)))
             if path is None:
                 plt.show()
             if path is not None and display is True:
